@@ -33,13 +33,13 @@ STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************************************************
 """
-from importlib_resources import files
 import json
 import logging
 import re
 import sys
 from typing import Optional
 
+from importlib_resources import files
 from lxml import etree
 
 # Gets or creates a logger
@@ -59,7 +59,7 @@ logger.addHandler(logging.StreamHandler(sys.stdout))
 
 # BuildingSync Schema location
 BUILDINGSYNC_SCHEMA_URL = "http://buildingsync.net/schemas/bedes-auc/2019"
-DEFAULT_ASSETS_DEF_FILE = 'asset_definitions.json' # in package's config directory
+DEFAULT_ASSETS_DEF_FILE = 'asset_definitions.json'  # in package's config directory
 
 
 # Processor class loads an XML file and extracts assets
@@ -75,7 +75,7 @@ class BSyncProcessor:
         self.filename = filename
 
         # use default asset definitions file unless otherwise specified
-        
+
         if asset_defs_filename:
             self.config_filename = asset_defs_filename
             # open abs path
@@ -148,7 +148,7 @@ class BSyncProcessor:
 
     def get_assets(self):
         """ return asset data """
-        return self.asset_data
+        return self.asset_data['assets']
 
     def save(self, filename: str):
         """ save assets data to JSON file
